"""This module contains core scripts for splitting files"""

# Standard Library
from os import path, mkdir

# Local
from .utils import path_exists, path_is_file


def split_into_parts(
    file_path: str, output_path: str, parts: int, prefix: str = "chunk_"
):
    """Splits provided file into chunks based on parts from total size of file

    Args:
        file_path (str): Path to the file to be splitted
        output_path (str): Output folder path
        parts (int): parts value for splitting
        prefix (str, optional): Optional prefix to chunks. Defaults to "chunk_".

    Raises:
        IOError: Raised if file at path does not exist
        IOError: Raised if resource at path is not a folder
    """

    if not path_is_file(file_path):
        raise IOError(f"File at path {file_path} does not exist!")

    if not path_exists(output_path):
        mkdir(output_path)

    with open(file_path, "rb") as mfile:
        content = bytearray(path.getsize(file_path))
        chunk_size = int(len(content) / parts)
        mfile.readinto(content)

        for count, i in enumerate(range(0, len(content), chunk_size)):
            with open(
                output_path + "/" + prefix + str(count) + path.basename(file_path), "wb"
            ) as chunk_file:
                chunk_file.write(content[i : i + chunk_size])



"""This module stores helpers for flitch project"""

# Standard Library
from os import path


def path_exists(resource_path: str) -> bool:
    """Checks if path exists

    Args:
        resource_path (str): Path to a resource in filesystem

    Returns:
        bool: Boolean response
    """
    return path.exists(resource_path)


def path_is_file(resource_path: str) -> bool:
    """Checks if path is file

    Args:
        resource_path (str): Path to a resource in filesystem

    Returns:
        bool: Boolean response
    """
    return path.exists(resource_path) and path.isfile(resource_path)


def path_is_folder(resource_path: str) -> bool:
    """Checks if a path is a folder

    Args:
        resource_path (str): Path to a resource in filesystem

    Returns:
        bool: Boolean response
    """
    return path.isdir(resource_path)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['flitch']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'flitch',
    'version': '0.1.3',
    'description': 'A simple text file splitting utility',
    'long_description': '<p align="center">\n    <img width=60% src="https://github.com/aorumbayev/flitch/blob/master/misc/logo-min.png?raw=true" border="0" />\n</p>\n\n<p align="center">\n <a href="https://opensource.org/licenses/MIT"><img src="https://github.com/aorumbayev/flitch/workflows/CI/badge.svg?branch=dev"></a>\n <a href="https://opensource.org/licenses/MIT"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>\n</p>\n\n<p align="center">\n  Flitch is a collection of simple utilities for splitting text files\n</p>\n\n## Table of contents\n\n- [Prerequisites](#prerequisites)\n- [Installation](#installation)\n- [Examples](#examples)\n- [Testing](#contributing)\n\n## Prerequisites\n\nThe following set of technologies is required to be installed:\n\n- [Python 3.6](https://www.python.org/downloads/release/python-360/) and higher\n- [Poetry](https://python-poetry.org) a python dependency manager\n\n## Installation\n\n```bash\npoetry install\n```\n\n## Examples\n\nThe following section demonstrates usage of various file splitting functions available.\n\n### Splitting text file into `n` parts\n\nExample below demonstrated a sample invocation of parts splitter.\n\n```python\nimport flitch\n\nflitch.split_into_parts("{input_file}", "{output_folder}", 10)\n```\n\nFor more details refer to [Documentation]()\n\n### Testing\n\nThe following assumes that all dependencies are installed and virtual environment is activated via `poetry`.\n\n```bash\npytest\n```\n',
    'author': 'Altynbek Orumbayev',
    'author_email': 'aorumbayev@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/python-poetry/poetry',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
